==> mDNSrelay.0.2.tar.gz: mDNSrelay/src/net/bakingpowder/mDNSrelay/Server/RecieveFromClientAndBroadcast.java <==
package net.bakingpowder.mDNSrelay.Server;

//import java.net.ConnectException;
import java.net.DatagramPacket;
import java.net.InetAddress;
import java.net.Socket;
import java.net.MulticastSocket;
//import java.net.UnknownHostException;
import java.io.IOException;
import java.io.InputStream;

//import java.io.OutputStream;

public class RecieveFromClientAndBroadcast implements Runnable {

	//󂯎ƂMulticast
	final static String MDNS_GROUP = "224.0.0.251";

	//final static String MDNS_GROUP_IPV6 = "FF02::FB";
	final static int MDNS_PORT = 5353;

	final static int BUFFER_SIZE = 4096;

	//q̏
	private String destHost = null;

	private String destRecieveTCPRelayAddress = null;

	private int destRecieveTCPRelayPort, destPortNumber;

	private boolean stopper = false;

	//}`LXg\Pbg
	MulticastSocket ms;

	Socket destSocket;

	
	java.util.Stack st;
	
	/**
	 * ݒp̃RXgN^
	 * 
	 * @param portNumber
	 * @param destRecieveTCPRelayAddress
	 * @param destRecieveTCPRelayPort
	 * @throws Exception
	 */
	public RecieveFromClientAndBroadcast(Socket cs,java.util.Stack st) throws Exception {
		this.st = st;
		destSocket = cs;
		ms = new MulticastSocket(MDNS_PORT);
		iams = InetAddress.getByName(MDNS_GROUP);
	}

	InetAddress iams;

	public void run() {

		try {
			InputStream srcIn = destSocket.getInputStream();
			byte[] buffer = new byte[4096];

			int i = 0;
			int totalbytes = 0;
			int bytesRead = 0;
			while (true) {
				try {
					if ((bytesRead = srcIn.read(buffer, 0, BUFFER_SIZE)) == -1) {
						break;
					}

					i++;
					totalbytes = totalbytes + bytesRead;
					
					System.out.print("packets from Client:" + i + " packets\t");
					
					if (totalbytes<1000){
					System.out.print("packets from Client Total:" + totalbytes + "bytes");
					} else if (totalbytes>=1000){
						System.out.print("packets from Client Total:" + ((int)(totalbytes/1000)) + "KBytes");
					}
					System.out.print("\r");
					
					DatagramPacket dp = new DatagramPacket(buffer,
							buffer.length, iams, MDNS_PORT);
					ms.setTimeToLive(254);
					//ms.setLoopbackMode(false);
					st.push(buffer);
					
					ms.send(dp);
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}

==> mDNSrelay.0.03.tar.gz: mDNSrelay/src/net/bakingpowder/mDNSrelay/Server/RecieveFromClientAndBroadcast.java <==
package net.bakingpowder.mDNSrelay.Server;

import java.net.DatagramPacket;
import java.net.InetAddress;
import java.net.Socket;
import java.net.MulticastSocket;
import java.io.IOException;
import java.io.InputStream;

public class RecieveFromClientAndBroadcast implements Runnable {

	final static String MDNS_GROUP = "224.0.0.251";

	//final static String MDNS_GROUP_IPV6 = "FF02::FB";
	final static int MDNS_PORT = 5353;

	final static int BUFFER_SIZE = 4096;

	//q̏
	private String destHost = null;

	private String destRecieveTCPRelayAddress = null;

	private int destRecieveTCPRelayPort, destPortNumber;

	private boolean stopper = false;

	//}`LXg\Pbg
	MulticastSocket ms;

	Socket destSocket;

//	java.util.Stack st;

	/**
	 * ݒp̃RXgN^
	 * 
	 * @param portNumber
	 * @param destRecieveTCPRelayAddress
	 * @param destRecieveTCPRelayPort
	 * @throws Exception
	 */
	public RecieveFromClientAndBroadcast(Socket cs)
			throws Exception {
	//	this.st = st;
		destSocket = cs;
		ms = new MulticastSocket(MDNS_PORT);
		iams = InetAddress.getByName(MDNS_GROUP);
	}

	InetAddress iams;

	public void run() {

		try {
			InputStream srcIn = destSocket.getInputStream();
			byte[] buffer = new byte[4096];

			int i = 0;
			int totalbytes = 0;
			int bytesRead = 0;
			while (true) {
				try {
					if ((bytesRead = srcIn.read(buffer, 0, BUFFER_SIZE)) == -1) {
						break;
					}

					i++;
					totalbytes = totalbytes + bytesRead;

					show(i,totalbytes);
					DatagramPacket dp = new DatagramPacket(buffer,
							buffer.length, iams, MDNS_PORT);
					ms.setTimeToLive(255);
					ms.send(dp);
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public static void show(int i,int totalbytes){
		System.out.print("packets from Client:" + i + " packets\t");

		if (totalbytes < 1000) {
			System.out.print("packets from Client Total:"
					+ totalbytes + "bytes");
		} else if (totalbytes >= 1000) {
			System.out.print("packets from Client Total:"
					+ ((int) (totalbytes / 1000)) + "KBytes");
		}
		System.out.print("\r");
		
	}
}
